**************
Nengo examples
**************

For more information about these examples, see the
`Nengo documentation <https://pythonhosted.org/nengo/examples.html>`_.

``basic``: Basic models
=======================

``2d_representation.ipynb``
  Represent a 2-dimensional signal.
``addition.ipynb``
  Add two scalar inputs.
``combining.ipynb``
  Combine two scalar inputs into a 2-dimensional vector.
``communication_channel.ipynb``
  Transmit a scalar from one ensemble to another unchanged.
``many_neurons.ipynb``
  Represent a sine wave with 100 LIF neurons.
``multiplication.ipynb``
  Multiply two scalars.
``single_neuron.ipynb``
  Represent a sine wave with 1 LIF neuron.
``squaring.ipynb``
  Square a scalar.
``two_neurons.ipynb``
  Represent a sine wave with 2 LIF neurons.

``advanced``: Advanced models
=============================

``inhibitory_gating.ipynb``
  Inhibit an ensemble with direct inhibitory input.
``izhikevich.ipynb``
  Use the Izhikevich neuron model in a Nengo ensemble.
``matrix_multiplication.ipynb``
  General matrix multiplication with an array of ensembles.
``nef_summary.ipynb``
  A summary of the 3 NEF principles that Nengo is based on.
``processes.ipynb``
  A tutorial on working with Processes.

``dynamics``: Models with dynamics
==================================

``controlled_integrator.ipynb``
  An integrator that can be turned off.
``controlled_integrator2.ipynb``
  An integrator whose integration speed can be controlled.
``controlled_oscillator.ipynb``
  An oscillator whose oscillation frequency can be controlled.
``integrator.ipynb``
  A simple scalar integrator.
``lorenz_attractor.ipynb``
  A chaotic 3-dimensional attractor.
``oscillator.ipynb``
  A simple harmonic oscillator.

``learning``: Models with learning
==================================

``learn_associations.ipynb``
  Learn an associative memory with the Voja rule.
``learn_communication_channel.ipynb``
  Learn a communication channel with the PES rule.
``learn_product.ipynb``
  Learn to compute the product with the PES rule.
``learn_square.ipynb``
  Learn to square a scalar with the PES rule.
``learn_unsupervised.ipynb``
  BCM and Oja rules applied to a communication channel.

``networks``: Models using built-in networks
============================================

``basal_ganglia.ipynb``
  Action selection network implemented according to basal ganglia physiology.
``ensemble_array.ipynb``
  An array of ensembles cooperating to represent a large vector space.
``integrator_network.ipynb``
  A simple integrator.

``spa``: Models using the SPA
=============================

``associative_memory.ipynb``
  Store and recall patterns with associative memories.
``convolution.ipynb``
  Bind two semantic pointers with circular convolution.
``question.ipynb``
  Answering cued questions with basal ganglia.
``question_control.ipynb``
  Answering explicit questions with basal ganglia and working memory.
``question_memory.ipynb``
  Answering cued questions with basal ganglia and working memory.
``spa_parser.ipynb``
  Parsing simple commands.
``spa_sequence.ipynb``
  Cycling through a sequence of five semantic pointers.
``spa_sequence_routed.ipynb``
  Cycling through a sequence of five semantic pointers, once a cue is presented.

``quirks``: Unexpected Nengo behavior
=====================================

``config.ipynb``
  Quirks of the config system that users should know.

``usage``: Nengo usage examples
===============================

``config.ipynb``
  Network defaults and backend-specific parameters using the ``config`` system.
``delay_node.ipynb``
  A simple node to delay a connection.
``exceptions.ipynb``
  All exceptions Nengo can raise and what they look like.
``network_design.ipynb``
  General principles for designing reusable networks.
``network_design_advanced.ipynb``
  More general principles for designing reusable networks.
``rectified_linear.ipynb``
  Extending Nengo by adding a new neuron model.
``strings.ipynb``
  String representations of Nengo objects.
``tuning_curves.ipynb``
  Plotting tuning and response curves of ensembles.
